package DBIx::Cookbook::DBIC::Sakila;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Schema';

__PACKAGE__->load_namespaces;


# Created by DBIx::Class::Schema::Loader v0.05003 @ 2010-03-24 17:44:05
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:AcJ3WJbybiTGcjx5HUL/Kw


# You can replace this text with custom content, and it will be preserved on regeneration
1;
